Update

Enum Update 

pub enum Update {
    ElapsedInMove(f32),
    Remaining(f32),
}
An update to a chess timer, based either on the new total seconds remaining or the seconds elapsed during the turn.

Variants



ElapsedInMove(f32)



Remaining(f32)

Implementations

Source

impl Update

pub fn read_annotation(annotation: &str) -> Result<Self, Err>

Reads a clock annotation in [%clk 0:00:00.0] format, returning Self::Remaining.

Errors

Returns an error if annotation does not match format.

pub fn write_annotation(time: f32) -> CompactString

Writes a clock annotation in [%clk 0:00:00.0] format.

pub const fn value(&self) -> f32

Get an update’s floating-point value.