pub enum Update {
ElapsedInMove(f32),
Remaining(f32),
}Expand description
An update to a chess timer, based either on the new total seconds remaining or the seconds elapsed during the turn.
Variants
Implementations
Sourceimpl Update
impl Update
Sourcepub fn read_annotation(annotation: &str) -> Result<Self, Err>
pub fn read_annotation(annotation: &str) -> Result<Self, Err>
Reads a clock annotation in [%clk 0:00:00.0] format, returning Self::Remaining.
Errors
Returns an error if annotation does not match format.
Sourcepub fn write_annotation(time: f32) -> CompactString
pub fn write_annotation(time: f32) -> CompactString
Writes a clock annotation in [%clk 0:00:00.0] format.